@@ -146,16 +146,16 @@ class Act(object):
                         if field in src:  # only update if src has field
                             parms[field] = src[field]
 
-            ioinits.update(self.ioinits or odict())
-            if self.prerefs: # preinits ioinits dict items
+            ioinits.update(self.ioinits or odict())  # self.ioinits 'do per'
+            if self.prerefs: # preinits ioinits dict items  'do for'
                 # each key is share src path, and value is list of src fields
                 for src, fields in self.prerefs.get('ioinits', {}).items():
                     src = self.resolvePath(ipath=src, warn=True) # now a share
                     if not fields:  # default is use existing fields
                         fields = self._prepareSrcFields(src, fields)
-                    for field in fields:  # requires src pre inited
+                    for field in fields:  # each src fld value pre inited with ipath
                         if field in src:  # only update if src has field
-                            ioinits[field] = src[field]
+                            ioinits[field] = src[field]  # clobbers ioinit odict() with ipath
             if ioinits:
                 iois = actor._initio(**ioinits)
                 if iois:
@@ -191,7 +191,7 @@ class Act(object):
         ipath may be path name of share or node
         or reference to Share or Node instance
 
-        This method resolves pathname strings into share and node references
+        This method resolves inline pathname strings into share and node references
         at resolve time.
 
         ival is optional value for share
@@ -201,7 +201,7 @@ class Act(object):
         if warn then will complain if the share is created.
 
         It allows for substitution into ipath of
-        frame, framer, actor, main frame, or main framer relative names.
+        inode, framer,  main framer, frame, main frame, or actor relative names.
         So that lexically relative pathnames can
         be dynamically resolved in support of framer cloning.
         It assumes that any implied variants have been reconciled.
@@ -214,17 +214,21 @@ class Act(object):
             If the path name starts with a leading '.' dot then path name is
             fully reconciled and no contextual substitutions are to be applied.
 
+            If the path name begins with 'me' then the path is inode relative
+
             Otherwise make subsitutions in pathname strings that begin
             with 'framer.'
-            Substitute for special path part 'framer' with names of 'me' or 'main'
-            Substitute for special path part 'frame' with names  of 'me' or 'main'
-            Substitute for special path part 'actor' with name of 'me'
+                Substitute for special path part 'framer' with names of 'me' or 'main'
+                Substitute for special path part 'frame' with names  of 'me' or 'main'
+                Substitute for special path part 'actor' with name of 'me'
+
+                'me' indicates substitute the current framer, frame, or actor name
+                respectively.
+
+                'main' indicates substitute the current frame's main framer or main frame
+                name respectively obtained from
 
-            'me' indicates substitute the current framer, frame, or actor name
-            respectively.
 
-            'main' indicates substitute the current frame's main framer or main frame
-            name respectively obtained from
 
         If ipath ends with a '.' then it resolves to a node
         Otherwise if not trailing dot it resolves to a share
@@ -561,10 +565,20 @@ class Actor(object):
         relative addressing is used.
 
         The inode is computed as absolute, relative, or default.
-        When not provided the default inode is  'framer.me.frame.me.actor.me.'
-        When the inode is relative it is relative to the framer inode
+        The default inode is  'framer.me.frame.me.actor.me.'
+            This occurs if the framer inode (finode) is empty
+                (which occurs when the via clause is missing for the framer)
+            and the ioinit inode paramter passed in is also empty
+
+        When a via clause exists for the framer then finode is not empty
+            so the default is not used
+            and the computed inode is either absolute or relative
+
+        When the inode parameter is relative (no leading dot)
+            it is relative to the framer inode
+
         If the framer is a cloned auxiliary then the inode could be relative
-          to the main framer inode
+            to the main framer inode
 
         The values of the items in the **kwa argument may be either strings or
         mappings
@@ -637,14 +651,14 @@ class Actor(object):
         finode = ''  # inode of framer
         if self._act.frame.framer:
             framer = self._act.frame.framer
-            finode = framer.inode
+            finode = framer.inode  # could be empty
             if framer.main:  # aux framer so special meaning of main or mine
                 if finode == "main":  # replace finode with main framer inode
                     finode = framer.main.framer.inode
                 elif finode == "mine":  # don't prepend main framer inode
                     finode = ""  # effectively empty inode
                 else:  # possibly prepend main framer inode if finode relative
-                    minode = framer.main.framer.inode
+                    minode = framer.main.framer.inode  # could be empty
                     minode = minode.rstrip('.')
                     if not finode.startswith('.') and minode:  # prepend if relative
                         finode = '.'.join([minode, finode])
@@ -662,16 +676,17 @@ class Actor(object):
 
         iois = odict()
 
-        for key, val in kwa.items():
-            if val is None:
-                continue
+        for key, val in kwa.items():  # assumes keys are basestrings
+            if val is None:  # use default assume no way to be inadvertent
+                val = ""  # empty string for val defaults ipath to same as key
+                #continue
 
             if isinstance(val, basestring):
                 ipath = val
                 iown = None
                 ival = odict() # effectively will not change share
             elif isinstance(val, Mapping): # dictionary
-                ipath = val.get('ipath')
+                ipath = val.get('ipath', '')
                 iown = val.get('iown')
 
                 if not 'ival' in val:
@@ -692,7 +707,7 @@ class Actor(object):
             if ipath:
                 if not ipath.startswith('.'): # full path is inode joined to ipath
                     ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
-            else:
+            else: # empty ipath
                 ipath = '.'.join((inode.rstrip('.'), key))  # when ipath empty create default from key
 
             if ipath.startswith('me.') or ipath == 'me':
